@@ -20,7 +20,7 @@ package Clownfish::CFC::Perl::Build::Charmonic;
 
 use base qw( Module::Build );
 
-our $VERSION = '0.004003';
+our $VERSION = '0.004003_002';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -91,7 +91,17 @@ sub ACTION_charmony {
     }
     print join( " ", @command ), $/;
 
-    system(@command) and die "Failed to run $CHARMONIZER_EXE_PATH: $!";
+    if ( system(@command) != 0 ) {
+        warn "Failed to run $CHARMONIZER_EXE_PATH: $!\n";
+
+        if ( ( $ENV{CHARM_VERBOSITY} || 0 ) < 2 ) {
+            print "Rerunning $CHARMONIZER_EXE_PATH with CHARM_VERBOSITY=2\n\n";
+            $ENV{CHARM_VERBOSITY} = 2;
+            system(@command);
+        }
+
+        die "Aborted";
+    }
 }
 
 my $config;
